@@ -1,6 +1,6 @@
 #' Prediction using dynamic random forests
 #'
-#' @param object \code{DynForest} object containing the dynamic random forest used on train data
+#' @param object \code{dynforest} object containing the dynamic random forest used on train data
 #' @param timeData A data.frame containing the id and time measurements variables and the time-dependent predictors.
 #' @param fixedData A data.frame containing the id variable and the time-fixed predictors. Non-continuous variables should be characterized as factor.
 #' @param idVar A character indicating the name of variable to identify the subjects
@@ -13,6 +13,8 @@
 #'
 #' @return Return the outcome of interest for the new subjects: matrix of probability of event of interest in survival mode, average value in regression mode and most likely value in classification mode
 #'
+#' @seealso [dynforest()]
+#'
 #' @examples
 #' \donttest{
 #' data(pbc2)
@@ -53,8 +55,8 @@
 #' Y <- list(type = "surv",
 #'           Y = unique(pbc2_train[,c("id","years","event")]))
 #'
-#' # Run DynForest function
-#' res_dyn <- DynForest(timeData = timeData_train, fixedData = fixedData_train,
+#' # Run dynforest function
+#' res_dyn <- dynforest(timeData = timeData_train, fixedData = fixedData_train,
 #'                      timeVar = "time", idVar = "id",
 #'                      timeVarModel = timeVarModel, Y = Y,
 #'                      ntree = 50, nodesize = 5, minsplit = 5,
@@ -75,20 +77,23 @@
 #'                     idVar = "id", timeVar = "time",
 #'                     t0 = 4)
 #' }
-#' @rdname predict.DynForest
+#' @rdname predict.dynforest
 #' @export
-predict.DynForest <- function(object,
+predict.dynforest <- function(object,
                               timeData = NULL, fixedData = NULL,
                               idVar, timeVar, t0 = NULL, ...){
 
   Longitudinal <- Factor <- Numeric <- NULL
 
-  if (!methods::is(object,"DynForest")){
-    stop("'object' should be an object of 'DynForest' class!")
+  if (!methods::is(object,"dynforest")){
+    cli_abort(c(
+      "{.var object} must be a dynforest object",
+      "x" = "You've supplied a {.cls {class(object)}} object"
+    ))
   }
 
   # checking function
-  checking(DynForest_obj = object,
+  checking(dynforest_obj = object,
            timeData = timeData, fixedData = fixedData,
            idVar = idVar, timeVar = timeVar)
 
@@ -96,7 +101,9 @@ predict.DynForest <- function(object,
   if (object$type=="surv"){
 
     if (is.null(t0)){
-      stop("t0 value is needed for dynamic prediction !")
+      cli_abort(c(
+        "{.var t0} can't be NULL"
+      ))
     }
 
   }
@@ -130,7 +137,9 @@ predict.DynForest <- function(object,
       timeData <- timeData[which(timeData[,idVar]%in%timeData_id_noNA),]
 
     }else{
-      stop("One measurement or more is required for each marker by subject!")
+      cli_abort(c(
+        "One measurement or more is required in {.var timeData} for each marker by subject"
+      ))
     }
 
     Inputs <- c(Inputs, "timeData")
@@ -339,7 +348,7 @@ predict.DynForest <- function(object,
                    t0 = t0)
   }
 
-  class(output) <- c("DynForestPred")
+  class(output) <- c("dynforestpred")
   return(output)
 
 }
